@@ -189,6 +189,10 @@
 /* Follow redirect responses on GET requests. */
 #define DAV_FOLLOW_REDIRECT 0
 
+/* Use Neon work around for SharePoint href-elements with characters
+   that are not allowed in href-elements. */
+#define DAV_SHAREPOINT_HREF_BUG 0
+
 /* Timeout in seconds used when libneon supports non blocking io
    A value of zero means use the TCP default
    May be overriden by system config file and user config file. */
